#
# spec file for package python-yacron
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-yacron
Version:        0.19.0
Release:        3.1
Summary:        Docker-friendly Cron replacement
License:        MIT
URL:            https://github.com/gjcarneiro/yacron
Source:         https://files.pythonhosted.org/packages/source/y/yacron/yacron-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Support Sentry SDK changes
Patch0:         support-new-sentry-sdk.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-aiohttp
Requires:       python-aiosmtplib
Requires:       python-crontab
Requires:       python-pytz
Requires:       python-ruamel.yaml
Requires:       python-sentry-sdk
Requires:       python-strictyaml >= 0.7.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module aiosmtplib}
BuildRequires:  %{python_module crontab}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module sentry-sdk}
BuildRequires:  %{python_module strictyaml >= 0.7.2}
# /SECTION
%python_subpackages

%description
A modern Cron replacement that is Docker-friendly.

%prep
%autosetup -p1 -n yacron-%{version}
sed -i 's/pytest-runner//;/pytest-cov/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/yacron
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative yacron

%postun
%python_uninstall_alternative yacron

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/yacron
%{python_sitelib}/yacron
%{python_sitelib}/yacron-%{version}.dist-info

%changelog
* Mon Jan  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-new-sentry-sdk.patch:
  * Support new Sentry SDK changes.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip python 3.9 due to missing dependencies
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.19.0:
  * Add ability to configure yacron's own logging (#81 #82 #83,
  * Add config value for SMTP(validate_certs=False) (David
    Batley)
  * fixes "Job is always executed immediately on yacron start"
    (#67)
  * add an `enabled` option in jobs (#73)
  * give a better error message when no configuration file is
    provided or exists (#72)
* Tue Aug 30 2022 Paul Barker <paul@pbarker.dev>
- Update to v0.17.0:
  * Changes in 0.17.0:
  * Support Additional Shell Report Vars
  * Shell reporter: handle long lines truncatation
  * exe: undo pyinstaller LD_LIBRARY_PATH changes in subprocesses
  * Changes in 0.16.0:
  * make the capture max line length configurable and change the default
    from 64K to 16M
  * Add config option to change prefix of subprocess stream lines
  * Changes in 0.15.1:
  * Fix a bug in the --validate option
  * Changes in 0.15.0:
  * Allow emails to be html formatted
  * Fix an error when reading cmd output with huge lines
  * Changes in 0.14.0:
  * Sentry: increase the size of messages before getting truncated
  * Sentry: allow specifying the environment option
  * Minor fixes
  * Changes in 0.13.1:
  * unicode fixes for the exe binary version
- Update dependencies to match the requirements listed in setup.py
* Thu Dec  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Skip python 3.6 since python-sentry-sdk dropped it
* Tue Aug 10 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.13.0:
  - Add ability for one config file to include another one
  - Add shell command reporting ability
  - web: don't crash when receiving a web request without Accept header
  - add env_file configuration option (Alessandro Romani, )
  - email: add missing Date header
  - Add back a self contained binary, this time based on PyInstaller
  - Fix email reporting when multiple recipients given
  - reporting: add a failure reason line at the top of sentry/email
  - mail: new tls, startls, username, and password options
  - allow jobs to run as a different user
  - Support timezone schedule
* Fri May 15 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 0.10.0
  * HTTP remote interface, allowing to get job status and start jobs on demand
  * Simple Linux binary including all dependencies (built using PyOxidizer)
  * Build Linux binary inside Docker Ubuntu 16.04, so that it is compatible with
    older glibc systems
  * Build a standalone Linux binary, using PyOxidizer
  * Switch from raven to sentry-sdk
* Wed Sep 11 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.9.0
